/* Distributed under the Apache License, Version 2.0.
   See accompanying NOTICE file for details.*/

// The following how-to functions demonstrate various ways of interacting with the Pulse engine
#include "howto/EngineHowTo.h"

#include "cdm/engine/SEDataRequestTracker.h"
#include "cdm/engine/SEDataRequest.h"
#include "cdm/properties/SEScalarTime.h"

int main()
{
  // Uncomment a method to execute fuctionality!

  //HowToSandbox();

  //HowToEngineUse();
  //HowToCreateAPatient();
  HowToSerialize();
  //HowToPulseEnginePool();

  //HowToACLS();
  //HowToAirwayObstruction();
  //HowToAnesthesiaMachine();
  //HowToArrythmia();
  //HowToAsthmaAttack();
  //HowToBagValveMask();
  //HowToBolusDrug();
  //HowToBrainInjury();
  //HowToCardiovascularMechanicsModification();
  //HowToCombatMultitrauma();
  //HowToConsumeNutrients();
  //HowToCOPD();
  //HowToCOVID19Ventilated();
  //HowToCPR();
  //HowToDehydration();
  //HowToECMO();
  //HowToEnvironmentChange();
  //HowToExercise();
  //HowToHemorrhage();
  //HowToIsoShuntAnalysis();
  //HowToExpandedRespiratory();
  //HowToExpandedRespiratoryAnalysis();
  //HowToExpandedVasculature();
  //HowToHemorrhage();
  //HowToHemothorax();
  //HowToPneumonia();
  //HowToMechanicalVentilation();
  //HowToMechanicalVentilator();
  //HowToPulmonaryFibrosis();
  //HowToRespiratoryMechanics();
  //HowToRespiratoryMechanicsModification();
  //HowToRunToStable();
  //HowToSmoke();
  //HowToTensionPneumothorax();
  //HowToVentilatorFeedbackLoop();

  // These ones do not really run, pure examples
  //HowToRunScenarios();
  //HowToScenarioFromLog();

  // More complicated examples that do run
  //HowToConcurrentEngines();
  //HowToDynamicHemorrhage();

  //HowToTestSystemCapability();

  //HowToVentilationMechanics();
}
